@@ -34,13 +34,13 @@ COMMAND_TYPE_REQUEST = 0x01
 COMMAND_TYPE_RESPONSE = 0x02
 
 DEVICE_ADDRESS = 0x41  # 7 bit address (will be left shifted to add the read write bit)
-
+BATTERY_TEMP_ADDRESS = 0x48 # This one uses when the battery holder is seperated from HAT.
 
 class Command:
     """ 
-	Command class for provide i2c communication requirements 
+    Command class for provide i2c communication requirements 
     of Sixfab Power API.
-	
+    
     Methods
     -------
     send_command : Function for sending command
@@ -96,7 +96,7 @@ class Command:
     PROTOCOL_COMMAND_SOFT_POWER_OFF = 36
     PROTOCOL_COMMAND_HARD_REBOOT = 37
     PROTOCOL_COMMAND_SOFT_REBOOT = 38
-    PROTOCOL_COMAMND_WATCHDOG_ALARM = 39
+    PROTOCOL_COMMAND_WATCHDOG_SIGNAL = 39
     PROTOCOL_COMMAND_GET_BATTERY_DESIGN_CAPACITY = 40
     PROTOCOL_COMMAND_SET_BATTERY_DESIGN_CAPACITY = 41
     PROTOCOL_COMMAND_HARD_POWER_ON = 42
@@ -106,6 +106,21 @@ class Command:
     PROTOCOL_COMMAND_GET_EASY_DEPLOYMENT_MODE = 46
     PROTOCOL_COMMAND_SET_LOW_POWER_MODE = 47
     PROTOCOL_COMMAND_SET_EASY_DEPLOYMENT_MODE = 48
+    PROTOCOL_COMMAND_SET_FAN_MODE = 49
+    PROTOCOL_COMMAND_GET_FAN_MODE = 50
+    PROTOCOL_COMMAND_GET_WATCHDOG_INTERVAL = 51
+    PROTOCOL_COMMAND_SET_WATCHDOG_INTERVAL = 52
+    PROTOCOL_COMMAND_GET_BATTERY_SEPARATION_STATUS = 53
+    PROTOCOL_COMMAND_SET_BATTERY_SEPARATION_STATUS = 54
+    PROTOCOL_COMMAND_SEND_BATTERY_TEMPERATURE = 55
+    PROTOCOL_COMMAND_GET_POWER_OUTAGE_PARAMS=56
+    PROTOCOL_COMMAND_SET_POWER_OUTAGE_PARAMS=57
+    PROTOCOL_COMMAND_GET_POWER_OUTAGE_EVENT_STATUS=58
+    PROTOCOL_COMMAND_SET_POWER_OUTAGE_EVENT_STATUS=59
+    PROTOCOL_COMMAND_GET_END_DEVICE_ALIVE_THRESHOLD=60
+    PROTOCOL_COMMAND_SET_END_DEVICE_ALIVE_THRESHOLD=61
+    PROTOCOL_COMMAND_GET_DEBUG_CONFIG=62
+    PROTOCOL_COMMAND_SET_DEBUG_CONFIG=63
     # .
     # .
     # .
@@ -317,3 +332,11 @@ class Command:
             return (crc_high, crc_low)
         else:
             return cal_crc
+
+    def read_word_data(self, address):
+        try:
+            word = bus.read_i2c_block_data(address, 0, 2)
+        except:
+            return -1
+        else:
+            return word
\ No newline at end of file
